@@ -2,7 +2,7 @@ import os
 from ConfigParser import ConfigParser
 from config import Config
 from owncloud import setup
-from trusted import Trusted
+from configmanager import ConfigManager
 from access import Access
 from https import Https
 
@@ -10,7 +10,8 @@ default_config_path = '/usr/local/config'
 
 
 class OwncloudControl:
-    def __init__(self, config, insider, access):
+    def __init__(self, config, insider, access, config_manager):
+        self.config_manager = config_manager
         self.config = config
         self.insider = insider
         self.access = access
@@ -19,6 +20,7 @@ class OwncloudControl:
         owncloud_url = 'http://{}:{}/{}'.format(host, self.config.port_http, self.config.url)
         setup.finish(owncloud_url, login, password)
         self.access.https_on()
+        self.config_manager.overwrite_webroot()
 
     def https_on(self):
         return self.access.https_on()
@@ -47,8 +49,8 @@ def get_control(insider, config_path=default_config_path):
     config_file = parser.get('owncloud', 'config_file')
 
     config = Config(service_name, port_http, service_type_http, port_https, service_type_https, url, config_file)
-    trusted = Trusted(config.config_file)
+    config_manager = ConfigManager(config.config_file)
     https = Https(config)
-    access = Access(config, insider, trusted, https)
+    access = Access(config, insider, config_manager, https)
 
-    return OwncloudControl(config, insider, access)
\ No newline at end of file
+    return OwncloudControl(config, insider, access, config_manager)
\ No newline at end of file
